@@ -404,13 +404,14 @@ class Arg(Argument):
         *args   : str,
         help    : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
+        nargs   : Union[omit, int, str] = omit,
         metavar : Optional[str] = None,
         group   : Optional[str] = None,
     ):
         """
         Used to add argparse arguments that contain a numeric sequence.
         """
-        return cls(*args, group=group, help=help, dest=dest, type=numseq, metavar=metavar)
+        return cls(*args, group=group, help=help, nargs=nargs, dest=dest, type=numseq, metavar=metavar)
 
     @classmethod
     def Number(
@@ -683,13 +684,16 @@ def UnitFilterBoilerplate(
 ) -> Callable[[Any, Iterable[Chunk]], Iterable[Chunk]]:
     @wraps(operation)
     def peekfilter(self, chunks: Iterable[Chunk]) -> Iterable[Chunk]:
-        def rewind(*head):
-            yield from head
+        def _apply_args_to_head():
+            it = iter(chunks)
+            for chunk in it:
+                if chunk.visible:
+                    yield self.args @ chunk
+                    break
+                else:
+                    yield chunk
             yield from it
-        it = iter(chunks)
-        for head in it:
-            yield from operation(self, rewind(self.args @ head))
-            break
+        yield from operation(self, _apply_args_to_head())
     return peekfilter
 
 
@@ -864,7 +868,7 @@ class Executable(ABCMeta):
 
     def __neg__(cls):
         unit = cls()
-        unit.args.reverse = True
+        unit.args.reverse = 1
         return unit
 
     def __ror__(cls, other) -> Unit:
@@ -1067,7 +1071,7 @@ class UnitBase(metaclass=Executable, abstract=True):
         `refinery.units.UnitBase`.
         """
 
-    @abc.abstractmethod
+    @abc.abstractclassmethod
     def handles(self, data: ByteString) -> Optional[bool]:
         """
         This tri-state routine returns `True` if the unit is certain that it can process the
@@ -1271,6 +1275,7 @@ class Unit(UnitBase, abstract=True):
     def filter(self, inputs: Iterable[Chunk]) -> Iterable[Chunk]:
         return inputs
 
+    @classmethod
     def handles(self, data: ByteString) -> Optional[bool]:
         return None
 
@@ -1333,7 +1338,7 @@ class Unit(UnitBase, abstract=True):
         cursor = self
         while isinstance(cursor, Unit):
             reversed = copy.copy(cursor)
-            reversed.args.reverse = True
+            reversed.args.reverse = 1
             reversed._source = None
             reversed.reset()
             pipeline.append(reversed)
@@ -1497,9 +1502,15 @@ class Unit(UnitBase, abstract=True):
         except StopIteration:
             return B''
 
-    def act(self, data: Union[Chunk, ByteString]) -> Optional[Chunk]:
-        op = self.reverse if self.args.reverse else self.process
-        return op(self.args @ data)
+    def act(self, data: Union[Chunk, ByteString]) -> Union[Optional[ByteString], Generator[ByteString, None, None]]:
+        mode = self.args.reverse
+        data = self.args @ data
+        if not mode:
+            return self.process(data)
+        elif mode > 1:
+            return self.reverse(self.process(data))
+        elif mode > 0:
+            return self.reverse(data)
 
     def __call__(self, data: Optional[Union[ByteString, Chunk]] = None) -> bytes:
         with MemoryFile(data) if data else open(os.devnull, 'rb') as stdin:
@@ -1517,7 +1528,7 @@ class Unit(UnitBase, abstract=True):
             return data
         return Chunk(data, meta=meta)
 
-    def process(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
+    def process(self, data: ByteString) -> Union[Optional[ByteString], Generator[ByteString, None, None]]:
         return data
 
     @classmethod
@@ -1610,7 +1621,8 @@ class Unit(UnitBase, abstract=True):
             help='Specify up to two times to increase log level.')
 
         if cls.is_reversible:
-            base.add_argument('-R', '--reverse', action='store_true', help='Use the reverse operation.')
+            base.add_argument('-R', '--reverse', action='count', default=0,
+                help='Use the reverse operation; Specify twice to normalize (first decode, then encode).')
 
         groups = {None: argp}
 
